
class Module:

    setting_failure_alerts = True
    setting_all_alerts = False
    setting_webhooks = []
    setting_enabled = True
    setting_schedule = '*/10 * * * *'
    setting_summary = """"""
    setting_teams_alerts = True
    setting_documentation_link = ''
    setting_exception_days = ['Saturday', 'Sunday']
    setting_start_time = '06:30'
    setting_end_time = '19:00'
    setting_bank_holidays = False
    setting_raise_tickets = False
